* fileread.cc (Input_file::open): Remove options parameter.
[deliverable/binutils-gdb.git] / bfd / nlm.c
index c941f72c4bc12e5e3c7151cd0e2004eb80cdf589..5cb8ac12e1cdf89f9a6fa8260162c5e8f2ed6bc3 100644 (file)
--- a/bfd/nlm.c
+++ b/bfd/nlm.c
@@ -1,40 +1,56 @@
 /* NLM (NetWare Loadable Module) executable support for BFD.
-   Copyright (C) 1993 Free Software Foundation, Inc.
+   Copyright 1993, 1994, 2001, 2002, 2003, 2005, 2007
+   Free Software Foundation, Inc.
 
-This file is part of BFD, the Binary File Descriptor library.
+   This file is part of BFD, the Binary File Descriptor library.
 
-This program is free software; you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation; either version 2 of the License, or
-(at your option) any later version.
+   This program is free software; you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation; either version 3 of the License, or
+   (at your option) any later version.
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
+   This program is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
 
-You should have received a copy of the GNU General Public License
-along with this program; if not, write to the Free Software
-Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.  */
+   You should have received a copy of the GNU General Public License
+   along with this program; if not, write to the Free Software
+   Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston,
+   MA 02110-1301, USA.  */
 
-#include "bfd.h"
 #include "sysdep.h"
+#include "bfd.h"
 #include "libbfd.h"
-#define ARCH_SIZE 0
 #include "libnlm.h"
 
-boolean
-DEFUN (nlm_mkobject, (abfd), bfd * abfd)
+/* Make an NLM object.  We just need to allocate the backend
+   information.  */
+
+bfd_boolean
+nlm_mkobject (bfd * abfd)
 {
-#if 0  /* nlm_object_p does the nlm_tdata allocation */
-  nlm_tdata (abfd) =
-    (struct nlm_obj_tdata *) bfd_zalloc (abfd, sizeof (struct nlm_obj_tdata));
+  bfd_size_type amt = sizeof (struct nlm_obj_tdata);
+
+  nlm_tdata (abfd) = bfd_zalloc (abfd, amt);
   if (nlm_tdata (abfd) == NULL)
-    {
-      bfd_error = no_memory;
-      return (false);
-    }
-#endif
-  /* since everything is done at close time, do we need any initialization? */
-  return (true);
+    return FALSE;
+
+  if (nlm_architecture (abfd) != bfd_arch_unknown)
+    bfd_default_set_arch_mach (abfd, nlm_architecture (abfd),
+                              nlm_machine (abfd));
+
+  /* Since everything is done at close time, do we need any initialization ?  */
+  return TRUE;
+}
+
+/* Set the architecture and machine for an NLM object.  */
+
+bfd_boolean
+nlm_set_arch_mach (bfd * abfd,
+                  enum bfd_architecture arch,
+                  unsigned long machine)
+{
+  bfd_default_set_arch_mach (abfd, arch, machine);
+  return arch == nlm_architecture (abfd);
 }
This page took 0.024211 seconds and 4 git commands to generate.